﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using Windows.ApplicationModel.Search;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Storage.Streams;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace SearchQueryList
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {

        public static MainPage Current;
        private SearchPane searchPane;
        internal const int SearchPaneMaxSuggestions = 5;

        private static readonly string[] suggestionList =
            {
                "Shanghai", "Istanbul", "Karachi", "Delhi", "Mumbai", "Moscow", "São Paulo", "Seoul", "Beijing", "Jakarta",
                "Tokyo", "Mexico City", "Kinshasa", "New York City", "Lagos", "London", "Lima", "Bogota", "Tehran", "Ho Chi Minh City",
                "Hong Kong", "Bangkok", "Dhaka", "Cairo", "Hanoi", "Rio de Janeiro", "Lahore", "Chonquing", "Bangalore", "Tianjin",
                "Baghdad", "Riyadh", "Singapore", "Santiago", "Saint Petersburg", "Surat", "Chennai", "Kolkata", "Yangon", "Guangzhou",
                "Alexandria", "Shenyang", "Hyderabad", "Ahmedabad", "Ankara", "Johannesburg", "Wuhan", "Los Angeles", "Yokohama",
                "Abidjan", "Busan", "Cape Town", "Durban", "Pune", "Jeddah", "Berlin", "Pyongyang", "Kanpur", "Madrid", "Jaipur",
                "Nairobi", "Chicago", "Houston", "Philadelphia", "Phoenix", "San Antonio", "San Diego", "Dallas", "San Jose",
                "Jacksonville", "Indianapolis", "San Francisco", "Austin", "Columbus", "Fort Worth", "Charlotte", "Detroit",
                "El Paso", "Memphis", "Baltimore", "Boston", "Seattle Washington", "Nashville", "Denver", "Louisville", "Milwaukee",
                "Portland", "Las Vegas", "Oklahoma City", "Albuquerque", "Tucson", "Fresno", "Sacramento", "Long Beach", "Kansas City",
                "Mesa", "Virginia Beach", "Atlanta", "Colorado Springs", "Omaha", "Raleigh", "Miami", "Cleveland", "Tulsa", "Oakland",
                "Minneapolis", "Wichita", "Arlington", " Bakersfield", "New Orleans", "Honolulu", "Anaheim", "Tampa", "Aurora",
                "Santa Ana", "St. Louis", "Pittsburgh", "Corpus Christi", "Riverside", "Cincinnati", "Lexington", "Anchorage",
                "Stockton", "Toledo", "St. Paul", "Newark", "Greensboro", "Buffalo", "Plano", "Lincoln", "Henderson", "Fort Wayne",
                "Jersey City", "St. Petersburg", "Chula Vista", "Norfolk", "Orlando", "Chandler", "Laredo", "Madison", "Winston-Salem",
                "Lubbock", "Baton Rouge", "Durham", "Garland", "Glendale", "Reno", "Hialeah", "Chesapeake", "Scottsdale",
                "North Las Vegas", "Irving", "Fremont", "Irvine", "Birmingham", "Rochester", "San Bernardino", "Spokane",
                "Toronto", "Montreal", "Vancouver", "Ottawa-Gatineau", "Calgary", "Edmonton", "Quebec City", "Winnipeg", "Hamilton"
            };


        public MainPage()
        {
            this.InitializeComponent();
            Current = this;
            searchPane = SearchPane.GetForCurrentView();
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            SearchPane.GetForCurrentView().QuerySubmitted += 
                new TypedEventHandler<SearchPane, SearchPaneQuerySubmittedEventArgs>
                    (OnQuerySubmitted);

            searchPane.SuggestionsRequested += 
                new TypedEventHandler<SearchPane, SearchPaneSuggestionsRequestedEventArgs>
                    (OnSearchPaneSuggestionsRequested);

            searchPane.ResultSuggestionChosen += OnSearchPaneResultSuggestionChosen;
        }

        void OnSearchPaneResultSuggestionChosen(SearchPane sender, SearchPaneResultSuggestionChosenEventArgs args)
        {
            // Demo: 3 - Show picked recommendation
           NotifyUser("Recommendation picked: " + args.Tag);
        }

        private void OnSearchPaneSuggestionsRequested(
            SearchPane sender, SearchPaneSuggestionsRequestedEventArgs e)
        {
            var queryText = e.QueryText;
            if (string.IsNullOrEmpty(queryText))
            {
               NotifyUser("Use the search pane to submit a query");
            }
            else
            {
                var request = e.Request;
                bool isRecommendationFound = false;
                foreach (string suggestion in suggestionList)
                {
                    // Demo: create a recommendation when full hit
                    if (suggestion.CompareTo(queryText) == 0)
                    {
                        // Add recommendation to Search Pane
                        RandomAccessStreamReference image = 
                            RandomAccessStreamReference.CreateFromUri(new Uri("ms-appx:///Assets/windows-sdk.png"));

                        request.SearchSuggestionCollection.AppendResultSuggestion(
                            suggestion,              // text to display 
                            "found " + suggestion,   // details
                            "tag " + suggestion,     // tags usable when called back by ResultSuggestionChosen event
                            image,                   // image if any
                            "image of " + suggestion // image alternate text
                            );
                        isRecommendationFound = true;
                    }
                    else  // otherwise, this is a suggestion
                        if (suggestion.StartsWith(queryText, StringComparison.CurrentCultureIgnoreCase))
                        {
                            // Add suggestion to Search Pane
                            request.SearchSuggestionCollection.AppendQuerySuggestion(suggestion);
                        }

                    // Break since the Search Pane can show at most 5 suggestions
                    if (request.SearchSuggestionCollection.Size >= MainPage.SearchPaneMaxSuggestions)
                    {
                        break;
                    }
                }

                if (request.SearchSuggestionCollection.Size > 0)
                {
                    // Demo: show if it is a recommendation or just a partial suggestion
                    string prefix = isRecommendationFound ? "* " : "";
                    NotifyUser(prefix + "Suggestions provided for query: " + queryText);
                }
                else
                {
                    NotifyUser("No suggestions provided for query: " + queryText);
                }
            }
        }



        internal void OnQuerySubmitted(object sender, SearchPaneQuerySubmittedEventArgs args)
        {
            ProcessQueryText(args.QueryText);
        }
        internal void ProcessQueryText(string queryText)
        {
            NotifyUser("Query submitted: " + queryText);
        }

        public void NotifyUser(string strMessage)
        {
            StatusBlock.Text = strMessage;
        }

    }
}
